// $Id: TotalPages.java 16463 2012-10-22 18:35:32Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.*;
import javax.swing.*;
import java.beans.*;
import java.awt.event.*;

/**
 * Creates a {@link JLabel} which displays the total number of pages on the Toolbar.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">TotalPages</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8
 */
public class TotalPages extends ViewerWidget implements DocumentPanelListener, PropertyChangeListener {

    private JLabel totalpages;
    private PDF pdf;

    public TotalPages() {
        super("TotalPages");
        totalpages = new JLabel();
        totalpages.setFont(null);
        totalpages.setHorizontalAlignment(JTextField.LEFT);
        totalpages.setText("/       ");
        setComponent("Navigation.ltr", totalpages);
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        viewer.addDocumentPanelListener(this);
    }

    public void documentUpdated(DocumentPanelEvent event) {
        if (event.getType().equals("activated") && event.getDocumentPanel().getPDF() != null) {
            pdf = event.getDocumentPanel().getPDF();
            pdf.addPropertyChangeListener(this);
            update();
        } else if (event.getType().equals("deactivated") && pdf != null) {
            pdf.removePropertyChangeListener(this);
            pdf = null;
            update();
        }
    }

    public void propertyChange(PropertyChangeEvent event) {
        if (event.getPropertyName().equals("pages")) {
            update();
        }
    }

    private void update() {
        if (pdf == null) {
            totalpages.setText("/       ");
        } else {
            totalpages.setText("/ "+pdf.getNumberOfPages());
        }
    }

}
